Python Source Extractor
=======================

This has been quite rigorously taken from TraP

https://github.com/transientskp/tkp/

and is probably not really ready for public usage yet!

available on pypi:

https://pypi.python.org/pypi/radio-pyse/0.1

```
$ pip install radio-pyse
```


